Properties Methods Events Config Options Direct Link

# Class Ext.ensible.cal.BoxLayoutTemplate

Package: | Ext.ensible.cal
Defined In: | BoxLayoutTemplate.js
Class: | BoxLayoutTemplate
Extends: | Object

This is the template used to render calendar views based on small day boxes within a non-scrolling container (currently the MonthView and the all-day headers for DayView and WeekView. This template is automatically bound to the underlying event store by the calendar components and expects records of type Ext.ensible.cal.EventRecord.

## Config Options

Config Options | Defined By
--- | ---
| firstWeekDateFormat : String The date format used for the day boxes in the first week of the view only (subsequent weeks use the otherWeeksDateFor... The date format used for the day boxes in the first week of the view only (subsequent weeks use the otherWeeksDateFormat config). Defaults to 'D j'. Note that if the day names header is displayed above the first row (e.g., MonthView.showHeader = true) then this value is ignored and otherWeeksDateFormat will be used instead. | BoxLayoutTemplate
| multiDayFirstDayFormat : String The date format used for the date in the header when more than one day are visible (defaults to 'M j, Y'). | BoxLayoutTemplate
| multiDayMonthStartFormat : String The date format to use for the first day in a month when more than one day are visible (defaults to 'M j'). Note that... The date format to use for the first day in a month when more than one day are visible (defaults to 'M j'). Note that if this day falls on the first day within the view, multiDayFirstDayFormat takes precedence. | BoxLayoutTemplate
| otherWeeksDateFormat : String The date format used for the date in day boxes (other than the first week, which is controlled by firstWeekDateFormat... The date format used for the date in day boxes (other than the first week, which is controlled by firstWeekDateFormat). Defaults to 'j'. | BoxLayoutTemplate
| singleDayDateFormat : String The date format used for the date in the header when in single-day view (defaults to 'l, F j, Y'). | BoxLayoutTemplate

## Public Properties

This class has no public properties.

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.